"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.UserRepository = void 0;
const tslib_1 = require("tslib");
// Copyright (c) 2023 Sourcefuse Technologies
//
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT
const core_1 = require("@loopback/core");
const repository_1 = require("@loopback/repository");
const sequelize_1 = require("@loopback/sequelize");
const core_2 = require("@sourceloop/core");
const sequelize_2 = require("loopback4-soft-delete/sequelize");
const keys_1 = require("../../keys");
const types_1 = require("../../types");
const otp_repository_1 = require("../otp.repository");
const user_credentials_repository_1 = require("./user-credentials.repository");
let UserRepository = class UserRepository extends sequelize_2.SequelizeSoftCrudRepository {
    constructor(dataSource, getUserCredsRepository, getOtpRepository, tenantRepositoryGetter, userTenantRepositoryGetter, logger, passwordDecryptionFn, user) {
        super(user, dataSource);
        this.getOtpRepository = getOtpRepository;
        this.tenantRepositoryGetter = tenantRepositoryGetter;
        this.userTenantRepositoryGetter = userTenantRepositoryGetter;
        this.logger = logger;
        this.passwordDecryptionFn = passwordDecryptionFn;
        this.user = user;
        this.userTenants = this.createHasManyRepositoryFactoryFor('userTenants', userTenantRepositoryGetter);
        this.registerInclusionResolver('userTenants', this.userTenants.inclusionResolver);
        this.tenant = this.createBelongsToAccessorFor('defaultTenant', tenantRepositoryGetter);
        this.registerInclusionResolver('defaultTenant', this.tenant.inclusionResolver);
        this.credentials = this.createHasOneRepositoryFactoryFor('credentials', getUserCredsRepository);
        this.registerInclusionResolver('credentials', this.credentials.inclusionResolver);
    }
};
exports.UserRepository = UserRepository;
exports.UserRepository = UserRepository = tslib_1.__decorate([
    tslib_1.__param(0, (0, core_1.inject)(`datasources.${types_1.AuthDbSourceName}`)),
    tslib_1.__param(1, repository_1.repository.getter(user_credentials_repository_1.UserCredentialsRepository)),
    tslib_1.__param(2, repository_1.repository.getter(otp_repository_1.OtpRepository)),
    tslib_1.__param(3, repository_1.repository.getter('TenantRepository')),
    tslib_1.__param(4, repository_1.repository.getter('UserTenantRepository')),
    tslib_1.__param(5, (0, core_1.inject)(core_2.LOGGER.LOGGER_INJECT)),
    tslib_1.__param(6, (0, core_1.inject)(keys_1.AuthServiceBindings.PASSWORD_DECRYPTION_PROVIDER)),
    tslib_1.__param(7, (0, core_1.inject)('models.User')),
    tslib_1.__metadata("design:paramtypes", [sequelize_1.SequelizeDataSource, Function, Function, Function, Function, Object, Function, Object])
], UserRepository);
//# sourceMappingURL=user.repository.js.map